# PEtab --- a data format for specifying parameter estimation problems in system biology

This repository describes *PEtab* --- a data format for specifying parameter estimation problems in system biology, provides a Python library for easy access and validation of *PEtab* files. See [doc/documentation_data_format.md](doc/documentation_data_format.md) for more info.

Where PEtab is used:

- Systems biology optimization [benchmark problem collection](https://github.com/LoosC/Benchmark-Models/issues)
- [pyPESTO](https://github.com/ICB-DCM/pyPESTO/)


